#########################################
'This code conducts the analyses and produces the figures from Lewis et al 2023 Animal Behavior.

rtg and rnl, 2 Jun 2023'
#########################################

#Load packages
library(coxme)
library(lme4)
library(lmerTest)
library(AICcmodavg)
library(viridis)
library(paletteer)
library(ggthemes)
library(vegan)
source("extraction.R")

#Import the data set
songs.with.intros=read.csv("Lewisetal2023_UnitTable_full.csv") #full songs with introductions
songs.without.intros=read.csv("Lewisetal2023_UnitTable_nointro.csv") #songs with introductions excluded

#Add the gaps to the songs.with.intros
nrow.swi=nrow(songs.with.intros)
songs.with.intros$gap.after=c(songs.with.intros$start[2:nrow.swi]-songs.with.intros$end[1:(nrow.swi-1)],NA)
songs.with.intros$gap.after[which(songs.with.intros$sound.files[1:(nrow.swi-1)]!=songs.with.intros$sound.files[2:nrow.swi])]=NA

#remove 4 notes that are separated from their songs by gaps greater than 1 s (and thus are do not meet our definition for being part of the intro)
songs.with.intros=songs.with.intros[-which(songs.with.intros$gap.after>1),]

#Set the focal data
work.dat=songs.without.intros

#Import the metadata that describes each bird
meta.data=read.csv("Lewisetal2023_metadata.csv")
meta.data=meta.data[order(meta.data$Bird.ID),]

#########################################
#This section computes the six temporal metrics (mean song duration (s), mean logged song tempo (log(notes/s)), mean logged gap duration (log(s)), standard deviation of logged gap duration (log(s)), gap score (unitless), gap variability score (unitless)) at the level of individual birds
#########################################

#Compute mean song duration in seconds
song.starts=aggregate(work.dat$start,by=list(work.dat$sound.files,work.dat$song_individual),min)
song.ends=aggregate(work.dat$end,by=list(work.dat$sound.files,work.dat$song_individual),max)
sum(song.starts$Group.1!=song.ends$Group.1) #sanity check
song.durations=song.ends
song.durations$x=song.ends$x-song.starts$x
temp.metrics=aggregate(song.durations$x,by=list(song.durations$Group.2),mean)
mean.logged.song.duration=aggregate(log(song.durations$x),by=list(song.durations$Group.2),mean)
colnames(temp.metrics)=c("Bird.ID","mean.song.duration")
temp.metrics$mean.logged.song.duration=mean.logged.song.duration$x

#Compute tempo (with songs weighted equally regardless of duration or number of notes)
notes.p.song=aggregate(rep(1,nrow(work.dat)),by=list(work.dat$sound.files,work.dat$song_individual),sum)
song.tempos=notes.p.song$x/song.durations$x
mean.tempos=aggregate(song.tempos,by=list(song.durations$Group.2),mean)
mean.logged.tempos=aggregate(log(song.tempos),by=list(song.durations$Group.2),mean)
temp.metrics$mean.song.tempo=mean.tempos$x
temp.metrics$mean.logged.song.tempo=mean.logged.tempos$x

#Compute mean notes per song and add to the data
mean.notes.per.song=aggregate(notes.p.song$x,by=list(notes.p.song$Group.2),mean)
temp.metrics$mean.notes.per.song=mean.notes.per.song$x[match(temp.metrics$Bird.ID,mean.notes.per.song$Group.1)]

#Compute mean logged gap duration and sd (with all gaps weighted equally)
mean.logged.gap.durations=aggregate(log(work.dat$gap.after),by=list(work.dat$song_individual),mean,na.rm=T)
temp.metrics$mean.logged.gap.duration=mean.logged.gap.durations$x
logged.gap.duration.sds=aggregate(log(work.dat$gap.after),by=list(work.dat$song_individual),sd,na.rm=T)
temp.metrics$logged.gap.duration.sd=logged.gap.duration.sds$x

#Compute gap score, where the population average weights each bird (rather than each transition) equally 
#add transition type to the data set
total.notes=nrow(work.dat)
work.dat$trans.type=NA
work.dat$trans.type[1:(total.notes-1)]=paste(work.dat$note_label[1:(total.notes-1)],"-",work.dat$note_label[2:total.notes],sep="")
work.dat$trans.type[which(work.dat$sound.files[1:(nrow.swi-1)]!=work.dat$sound.files[2:nrow.swi])]=NA
#remove notes with no gaps after them (ie, the last note in each song)
gap.dat=work.dat[which(!is.na(work.dat$gap.after)),]
gap.dat=gap.dat[which(!is.na(gap.dat$trans.type)),]  #there seems to be a gap length after the last note in the last song of bird JS0003. I have excluded this from the population average because I do not know what it means, or what gap type it describes.
#compute the mean logged gap length (ie, the logged geometric mean) for each transition type in the population
tt.dur.pop=aggregate(log(gap.dat$gap.after),by=list(gap.dat$trans.type),mean)
#get the deviation of each duration from the population mean for its transition type
gap.dat$gap.dev=log(gap.dat$gap.after)-tt.dur.pop$x[match(gap.dat$trans.type,tt.dur.pop$Group.1)]
#add gap score to the data
gap.scores=aggregate(gap.dat$gap.dev,by=list(gap.dat$song_individual),mean)
temp.metrics$gap.score=gap.scores$x[match(temp.metrics$Bird.ID,gap.scores$Group.1)]

#Compute the gap variability score (not using CoV as in the original submission, but rather sd)
#compute the variance of the logged gap duration for each transition type as produced by each bird
var.x.tt.x.bird=aggregate(log(gap.dat$gap.after),by=list(gap.dat$trans.type,gap.dat$song_individual),var)
#check to see if the variance of note types is approximately independent of the duration. The regression below shows that variance is approximately independent of gap duration, so our gap variability score is not confounded by gap durations
dur.x.tt.x.bird=aggregate(log(gap.dat$gap.after),by=list(gap.dat$trans.type,gap.dat$song_individual),mean)
plot(dur.x.tt.x.bird$x,log(var.x.tt.x.bird$x))
summary(lm(var.x.tt.x.bird$x~dur.x.tt.x.bird$x))
#compute the number of times each bird produced each transition type
tt.count.x.bird=aggregate(rep(1,nrow(gap.dat)),by=list(gap.dat$trans.type,gap.dat$song_individual),sum) 
#sum the variances weighted for the number of times they were produced, less 1 for each bird
summed.weighted.vars=aggregate(var.x.tt.x.bird$x*(tt.count.x.bird$x-1),by=list(var.x.tt.x.bird$Group.1),sum,na.rm=T) 
#count the number of times each transition was produced in the population, less 1 for each bird that produced it
summed.counts=aggregate((tt.count.x.bird$x-1),by=list(var.x.tt.x.bird$Group.1),sum)
#scale the summed sds to get a population weighted mean sd for each transition type
weighted.var.x.tt=summed.weighted.vars$x/summed.counts$x
#compare sd for each note type produced by each bird to the population weighted mean for that note type, and log
var.score.bird.x.tt=log(var.x.tt.x.bird$x/weighted.var.x.tt[match(var.x.tt.x.bird$Group.1,summed.weighted.vars$Group.1)])
#sum the standardised sds for the transition types within birds, weighting for the number of times they were produced less 1
weighted.var.within.birds=aggregate(var.score.bird.x.tt*(tt.count.x.bird$x-1),by=list(var.x.tt.x.bird$Group.2),sum,na.rm=T)
#count the number of times notes each bird produced each note type, less 1 for each note type he produced
summed.counts.within.birds=aggregate((tt.count.x.bird$x-1),by=list(var.x.tt.x.bird$Group.2),sum)
#the variability score is the weighted mean within birds
temp.metrics$var.score=weighted.var.within.birds$x/summed.counts.within.birds$x

#########################################
#This section analyses the metrics that are computed at the level of individual birds
#########################################

#Add social father, clutch, bird age, and an indicator for cross-fostering to temp.metrics
temp.metrics$sf=meta.data$Social.Father[match(temp.metrics$Bird.ID,meta.data$Bird.ID)]
temp.metrics$clutch=meta.data$Clutch[match(temp.metrics$Bird.ID,meta.data$Bird.ID)]
temp.metrics$bird.age=meta.data$Age_Rec[match(temp.metrics$Bird.ID,meta.data$Bird.ID)]
temp.metrics$cross.foss=(meta.data$Social.Father[match(temp.metrics$Bird.ID,meta.data$Bird.ID)]!=meta.data$Genetic.Father[match(temp.metrics$Bird.ID,meta.data$Bird.ID)]) | (!is.na(meta.data$Social.Father[match(temp.metrics$Bird.ID,meta.data$Bird.ID)]) & is.na(meta.data$Genetic.Father[match(temp.metrics$Bird.ID,meta.data$Bird.ID)]))

#Add the change in log age of father from rearing of sons to recording
sf.age.at.rec=as.Date(meta.data$DOR[match(temp.metrics$sf,meta.data$Bird.ID)])-as.Date(meta.data$Birth.Date[match(temp.metrics$sf,meta.data$Bird.ID)])
sf.age.at.rear=as.Date(meta.data$Birth.Date[match(temp.metrics$Bird.ID,meta.data$Bird.ID)])-as.Date(meta.data$Birth.Date[match(temp.metrics$sf,meta.data$Bird.ID)])
temp.metrics$delta.log.sf.age=log(as.numeric(sf.age.at.rec))-log(as.numeric(sf.age.at.rear))

#Add logged intro length to the temp.metrics data
#count notes in intros
notes.swi=aggregate(rep(1,nrow(songs.with.intros)),by=list(songs.with.intros$sound.files),sum)
notes.swoi=aggregate(rep(1,nrow(songs.without.intros)),by=list(songs.without.intros$sound.files),sum)
#find the missing song
ms=notes.swi$Group.1[-which(notes.swi$Group.1 %in% notes.swoi$Group.1)]
songs.with.intros[which(songs.with.intros$sound.files==ms),]
#on inspection, we see that this series of notes is, by our definition, all introduction. In practice, we do not know if this an introduction followed by a very short song, or a just an introduction without a song. So, we will exclude it from the analysis of introduction length. We note that this bird is weird - his song includes almost exclusively one note type. Thus, we might wonder if this is really a song at all, or if this series of notes serves some other purpose. However, on inspection, we see that this bird's social sons and grandsons sing similarly depauperate songs. So, we have included all of these birds in the main analyses.
#compute intro lengths
intro.length=notes.swi$x[match(notes.swoi$Group.1,notes.swi$Group.1)]-notes.swoi$x
#add 0.5 to intros of length 0 to allow analysis of logged intro length
intro.length[which(intro.length==0)]=0.5
#collect means for individual birds
intro.dat=aggregate(log(intro.length),by=list(substr(notes.swoi$Group.1,1,6)),mean)
colnames(intro.dat)=c("bird.id","log.intro.length")
#add to temp.metrics
temp.metrics$log.intro.length=intro.dat$log.intro.length[match(temp.metrics$Bird.ID,intro.dat$bird.id)]

#Load kinship matrices produced for Lewis et al. 2021 Frontiers in Psychology
kin.trim = readRDS(file="kin.trim.rds")
null.kin = readRDS(file="null.kin.rds")

main.labs=c("mean song duration (s)","mean logged song duration (log(s))","mean song tempo (notes/s)","mean logged song tempo (log(notes/s))","mean logged gap duration (log(s))","sd of logged gap duration (log(s))","gap score","gap variability score","logged introduction length (log(notes))")

y.labs=c("mean song duration","mean logged song duration","mean song tempo","mean logged song tempo","mean logged gap duration","sd of logged gap duration","","","logged introduction length")

y.units=c("(s)","(log(s))","tempo\n(notes/s)","(log(notes/s))","(log(s))","(log(s))","gap score","gap variability score","log(notes)")

#Set metric to study, from: *mean.song.duration, mean.logged.song.duration, mean.song.tempo, *mean.logged.song.tempo, *mean.logged.gap.duration, *logged.gap.duration.sd, *gap.score, *var.score, *log.intro.length. Response variables makred with * are studied in the paper.
focal.metric="var.score"

#Get the social fathers' metrics
sf.metric=temp.metrics[match(temp.metrics$sf,temp.metrics$Bird.ID),which(colnames(temp.metrics)==focal.metric)]

#Fit models with no age correction
fmla.full=as.formula(paste(focal.metric,"~ sf.metric + I(log(bird.age)) + (1|Bird.ID) + (1|clutch)"))
m.na.full=lmekin(fmla.full, varlist = 2*kin.trim, data = temp.metrics)

fmla.kin=as.formula(paste(focal.metric,"~ sf.metric + I(log(bird.age)) + (1|Bird.ID)"))
m.na.kin=lmekin(fmla.kin, varlist = 2*kin.trim, data = temp.metrics)

fmla.clutch=as.formula(paste(focal.metric,"~ sf.metric + I(log(bird.age)) + (1|Bird.ID) + (1|clutch)"))
m.na.clutch=lmekin(fmla.clutch, varlist = null.kin, data = temp.metrics)

fmla.null=as.formula(paste(focal.metric,"~ sf.metric + I(log(bird.age)) + (1|Bird.ID)"))
m.na.null=lmekin(fmla.null, varlist = null.kin, data = temp.metrics)

#Collect results with no age correction
cox.tab=extract_coxme_table(m.na.full)
no.ped=1-pchisq(2*(m.na.full$loglik - m.na.clutch$loglik),1)
no.clutch=1-pchisq(2*(m.na.full$loglik - m.na.kin$loglik),1)
neither=1-pchisq(2*(m.na.full$loglik - m.na.null$loglik),2)
fitted.vals=data.frame(m.na.full[[1]][[1]][2],cox.tab[2,4],m.na.full[[1]][[1]][3],cox.tab[3,4],no.ped,no.clutch,neither)
colnames(fitted.vals)=c("sf effect","sf p-value","log age","log age p","pedigree p","clutch p","either p")

#Correct for father's age
delta.age.effect=1
age.ef.est=m.na.full[[1]][[1]][3]
while (abs(delta.age.effect)>10^-5){
  
  #correct sf phenotype to reflect age at rearing
  sf.metric.at.rearing=sf.metric-temp.metrics$delta.log.sf.age*age.ef.est
  
  #fit model
  fmla.full.aa=as.formula(paste(focal.metric,"~ sf.metric.at.rearing + I(log(bird.age)) + (1|Bird.ID) + (1|clutch)"))
  m.na.full.aa=lmekin(fmla.full.aa, varlist = 2*kin.trim, data = temp.metrics, method="ML")
  
  #check to see if we have finished
  delta.age.effect=m.na.full.aa[[1]][[1]][3]-age.ef.est
  age.ef.est=m.na.full.aa[[1]][[1]][3]
  
}

#Fit models with age correction
fmla.kin.aa=as.formula(paste(focal.metric,"~ sf.metric.at.rearing + I(log(bird.age)) + (1|Bird.ID)"))
m.na.kin.aa=lmekin(fmla.kin.aa, varlist = 2*kin.trim, data = temp.metrics, method="ML")

fmla.clutch.aa=as.formula(paste(focal.metric,"~ sf.metric.at.rearing + I(log(bird.age)) + (1|Bird.ID) + (1|clutch)"))
m.na.clutch.aa=lmekin(fmla.clutch.aa, varlist = null.kin, data = temp.metrics, method="ML")

fmla.null.aa=as.formula(paste(focal.metric,"~ sf.metric.at.rearing + I(log(bird.age)) + (1|Bird.ID)"))
m.na.null.aa=lmekin(fmla.null.aa, varlist = null.kin, data = temp.metrics, method="ML")

#Collect results with age correction
cox.tab.aa=extract_coxme_table(m.na.full.aa)
no.ped.aa=1-pchisq(2*(m.na.full.aa$loglik - m.na.clutch.aa$loglik),1)
no.clutch.aa=1-pchisq(2*(m.na.full.aa$loglik - m.na.kin.aa$loglik),1)
neither.aa=1-pchisq(2*(m.na.full.aa$loglik - m.na.null.aa$loglik),2)
fitted.vals=rbind(fitted.vals,c(m.na.full.aa[[1]][[1]][2],cox.tab.aa[2,4],m.na.full.aa[[1]][[1]][3],cox.tab.aa[3,4],no.ped.aa,no.clutch.aa,neither.aa))
rownames(fitted.vals)=c("w/o age correction","w/ age correction")

#Report the results
fitted.vals

#Test the hypothesis that the regression slope differs from 1:1. The p-value will be associated with the regression line in the model reg.2.mean.
fmla.r2m=as.formula(paste("(",focal.metric,"-sf.metric.at.rearing)~ sf.metric.at.rearing + I(log(bird.age)) + (1|Bird.ID) + (1|clutch)"))
reg.to.mean=lmekin(fmla.r2m, varlist = 2*kin.trim, data = temp.metrics, method="ML")
reg.to.mean

#Make figures showing effects of social fathers (points are raw data, but regression lines are age-corrected)
par(las=1)
son.metric=temp.metrics[,which(colnames(temp.metrics)==focal.metric)]
plot.range=c(min(son.metric)-0.05*(max(son.metric)-min(son.metric)),max(son.metric)+0.05*(max(son.metric)-min(son.metric)))
plot(sf.metric,son.metric,pch=1-temp.metrics$cross.foss,xlim=plot.range,ylim=plot.range,xlab="",ylab="",yaxt="n",xaxt="n")
l.det=as.numeric(cox.tab.aa[2,4]>0.05)
abline(m.na.full.aa[[1]][[1]][1]+mean(log(temp.metrics$bird.age))*m.na.full.aa[[1]][[1]][3],m.na.full.aa[[1]][[1]][2],lty=(l.det+1),col="blue")
abline(0,1)
#title(main=main.labs[which(colnames(temp.metrics)==focal.metric)-1],cex.main=1,font.main=1)
axis(1, lwd=0, lwd.ticks=2.5, tck=-0.04)
axis(2, lwd=0, lwd.ticks=2.5, tck=-0.04)
foc.met=main.labs[which(colnames(temp.metrics)==focal.metric)-2]
title(ylab=paste("son's",foc.met),line=2.5)
title(xlab=paste("social father's",foc.met),line=2)

#Make figures showing effects of age 
plot(log(temp.metrics$bird.age),son.metric,pch=1-temp.metrics$cross.foss,xlab="",ylab="",yaxt="n",xaxt="n")
l.det=as.numeric(cox.tab.aa[3,4]>0.05)
abline(m.na.full.aa[[1]][[1]][1]+mean(sf.metric.at.rearing,na.rm=T)*m.na.full.aa[[1]][[1]][2],m.na.full.aa[[1]][[1]][3],lty=(l.det+1),col="blue")
axis(1, lwd=0, lwd.ticks=2.5, tck=-0.03)
axis(2, lwd=0, lwd.ticks=2.5, tck=-0.03)
title(xlab="log age (y)",line=2)
title(ylab=paste(y.labs[which(colnames(temp.metrics)==focal.metric)-2],y.units[which(colnames(temp.metrics)==focal.metric)-2]),line=2.6)



#########################################
'This section studies whether gap duration depends on:
  
1. the note before (random effect)
2. the note after (random effect)
3. the interaction between these notes (random effect)
4. the duration of the note before
5. the duration of the note after
6. the number of notes in the song
7. the repertoire size of the singer
8. the Shannon diversity of the singers repertoire
9. the social father gap duration
10. the social father gap score
11. the age of the singer
12. the position of the gap in the song
13. the proportion of the all gaps produced by the bird that were of the focal gap type 
14. brood size of the focal bird
15. the bird ID (random effect)
16. the social father ID (random effect)
17. the clutch ID (random effect)

The social father ID explains the variability better than the clutch ID, but not significantly so. We cannot fit the model with both included b/c the fit becomes singular - essentially the model cannot decide where to assign variability - so we have to remove one. Below I have removed social father, but we could change this and remove clutch instead. None of the results change.' 
#########################################

#Create a new data frame to which we will add new columns describing the data
gl=work.dat

#Put note durations and gap durations on the same scale, and rename for clarity
gl$duration=gl$duration/1000 
colnames(gl)[which(colnames(gl)=="duration")]="dur.note.before"
colnames(gl)[which(colnames(gl)=="note_label")]="class.note.before"
colnames(gl)[which(colnames(gl)=="gap.after")]="gap.duration"

#Add the label and duration of the note after each gap to gl
gl$class.note.after=c(gl$class.note.before[2:length(gl$class.note.before)],NA)
gl$class.note.after[which(gl$sound.files[1:(nrow.swi-1)]!=gl$sound.files[2:nrow.swi])]=NA
gl$dur.note.after=c(gl$dur.note.before[2:length(gl$dur.note.before)],NA)
gl$dur.note.after[which(gl$sound.files[1:(nrow.swi-1)]!=gl$sound.files[2:nrow.swi])]=NA

#Remove last notes from each song (because there are no gaps after them)
gls=gl[which(!is.na(gl$gap.duration)),]
gls=gl[which(!is.na(gls$class.note.after)),]

#Add information about rearing to data set
gls$sf=meta.data$Social.Father[match(gls$song_individual,meta.data$Bird.ID)]
gls$sf.log.gap.dur=temp.metrics$mean.logged.gap.duration[match(gls$sf,temp.metrics$Bird.ID)]
gls$sf.gap.dur=exp(gls$sf.log.gap.dur)
gls$sf.gap.score=temp.metrics$gap.score[match(gls$sf,temp.metrics$Bird.ID)]
gls$clutch=meta.data$Clutch[match(gls$song_individual,meta.data$Bird.ID)]
gls$bird.age=temp.metrics$bird.age[match(gls$song_individual,temp.metrics$Bird.ID)]

#Add repertoire size and complexity to the data set
rsc=data.frame(BirdID=character(),rep.size=numeric(),rep.comp=numeric())
for (i in unique(gl$song_individual)){
  dat2use=gl[which(gl$song_individual==i),]
  bird.rs=length(unique(dat2use$class.note.before))
  nl.tab=aggregate(rep(1,nrow(dat2use)),by=list(dat2use$class.note.before),sum)
  nl.tab$x=nl.tab$x/sum(nl.tab$x)
  bird.rc=-sum(nl.tab$x*log(nl.tab$x))
  rsc=rbind(rsc,data.frame(i,bird.rs,bird.rc))
}
#add repertoire characteristics to data set
gls$bird.rs=rsc$bird.rs[match(gls$song_individual,rsc$i)]
gls$bird.rc=rsc$bird.rc[match(gls$song_individual,rsc$i)]

#Add song lengths to data set
sl.tab=aggregate(rep(1,nrow(gl)),by=list(gl$sound.files),sum)
gls$song.length=sl.tab$x[match(gls$sound.files,sl.tab$Group.1)]

#Add proportional frequency with which birds sang transition types to the model
gls$gt.ind=paste(gls$trans.type,gls$song_individual)
gt.ind.table=aggregate(rep(1,nrow(gls)),by=list(gls$gt.ind),sum)
gls$gt.freq=gt.ind.table$x[match(gls$gt.ind,gt.ind.table$Group.1)]
note.tot.table=aggregate(rep(1,nrow(gls)),by=list(gls$song_individual),sum)
gls$note.tot=note.tot.table$x[match(gls$song_individual,note.tot.table$Group.1)]
gls$gt.prop=gls$gt.freq/gls$note.tot

#Add brood size to data set
gls$brood.size=meta.data$Brood.Size[match(gls$song_individual,meta.data$Bird.ID)]

#Add transition type and social father identifier to gls
gls$gt.sf=paste(gls$trans.type,gls$sf)
bird.by.gap.type=aggregate(log(gls$gap.duration),by=list(gls$gt.ind),mean)
#add the social father logged gap duration for the same transitions type to the data set
gls$sf.mt.dur=bird.by.gap.type$x[match(gls$gt.sf,bird.by.gap.type$Group.1)]
#get the proportion of times each social father sings each note
gls$sf.gt.prop=gls$gt.prop[match(gls$gt.sf,gls$gt.ind)]

#Add the Jaccard distance between fathers' and sons' songs to the data set
b.x.gt=matrix(rep(0,length(unique(gls$song_individual))*length(unique(gls$trans.type))),nrow=length(unique(gls$song_individual)))
colnames(b.x.gt)=unique(gls$trans.type)
rownames(b.x.gt)=unique(gls$song_individual)
i=0
for (b in unique(gls$song_individual)){
  i=i+1
  j=0
  for (gt in unique(gls$trans.type)){
    j=j+1
    if (length(which(gls$trans.type==gt & gls$song_individual==b))>0){
      b.x.gt[i,j]=gls$gt.freq[which(gls$trans.type==gt & gls$song_individual==b)][1]
    }
  }
  b.x.gt[i,]=b.x.gt[i,]/sum(b.x.gt[i,])
}
jd.mat=as.matrix(vegdist(b.x.gt,method="jaccard"))
gls$f.s.jaccard=jd.mat[cbind(match(gls$song_individual,rownames(jd.mat)),match(gls$sf,colnames(jd.mat)))]

#To make it easier to interpret interactions, let's mean center the social father's mean matched-type gap durations
gls$sf.mt.dur.mc=gls$sf.mt.dur-mean(gls$sf.mt.dur,na.rm=T)

#Analyse the durations of each gap as produced by each bird. We will fit the full model, and then remove random effects with no variance until we get a fitting that is not singular. Then, we will use backwards selection to get the best model for the logged gap durations. Backwards selection can be problematic, but in this case the predictors have mostly extremely significant effects or none at all. We do not think there are better models hiding in the set of possible models. It would be a pain to test them all because the fitting is slow. If we want to the p-values associated with any of the predictors we have removed, we can add that predictor back to the "best" model at the end and get its p-value from that. (We can also use this adding back in process to test the final model.)

gd.ns.lme=lmer(log(gap.duration)~I(log(dur.note.before))+I(log(dur.note.after))+I(log(bird.rs))+bird.rc+gt.prop+I(log(song.length))+sf.log.gap.dur+sf.gap.score+I(log(bird.age))+selec+brood.size*sf.log.gap.dur+(1|sound.files)+(1|song_individual)+(1|class.note.before)+(1|class.note.after)+(1|trans.type)+(1|class.note.after:song_individual)+(1|class.note.before:song_individual)+(1|class.note.before:class.note.after:song_individual)+(1|clutch),data=gls,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=100000)))
summary(gd.ns.lme)
AICc(gd.ns.lme)

#best model for gap durations in songs with intros
gd.ns.lme=lmer(log(gap.duration)~I(log(dur.note.before))+I(log(dur.note.after))+gt.prop+I(log(song.length))+sf.log.gap.dur+selec+(1|class.note.before)+(1|class.note.after)+(1|trans.type)+(1|class.note.after:song_individual)+(1|class.note.before:song_individual)+(1|class.note.before:class.note.after:song_individual)+(1|clutch),data=gls,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=100000)))
summary(gd.ns.lme)
AICc(gd.ns.lme)

#best model for gap durations in songs without intros
gd.ns.lme=lmer(log(gap.duration)~I(log(dur.note.before))+I(log(dur.note.after))+gt.prop+sf.log.gap.dur+(1|song_individual)+(1|class.note.before)+(1|class.note.after)+(1|trans.type)+(1|class.note.after:song_individual)+(1|class.note.before:song_individual)+(1|class.note.before:class.note.after:song_individual)+(1|clutch),data=gls,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=100000)))
summary(gd.ns.lme)
AICc(gd.ns.lme)

#Analyse logged durations of gap types shared by fathers and sons. 

gd.lme=lmer(log(gap.duration)~I(log(dur.note.before))+I(log(dur.note.after))+I(log(bird.rs))+bird.rc+gt.prop+I(log(song.length))+sf.mt.dur+I(log(bird.age))+selec+brood.size*sf.mt.dur+sf.gt.prop*sf.mt.dur+sf.mt.dur*f.s.jaccard+(1|sound.files)+(1|song_individual)+(1|class.note.before)+(1|class.note.after)+(1|trans.type)+(1|class.note.after:song_individual)+(1|class.note.before:song_individual)+(1|class.note.before:class.note.after:song_individual)+(1|clutch),data=gls,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=100000)))
summary(gd.lme)
AICc(gd.lme)

#best model for shared gap durations in songs with intros
gd.lme=lmer(log(gap.duration)~I(log(dur.note.before))+I(log(dur.note.after))+bird.rc+I(log(song.length))+sf.mt.dur.mc+selec+sf.mt.dur.mc*f.s.jaccard+(1|class.note.before)+(1|class.note.after)+(1|trans.type)+(1|class.note.after:song_individual)+(1|class.note.before:song_individual)+(1|class.note.before:class.note.after:song_individual)+(1|clutch),data=gls,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=100000)))
summary(gd.lme)
AICc(gd.lme)

#best model for shared gap durations in songs without intros
gd.lme=lmer(log(gap.duration)~I(log(dur.note.before))+I(log(dur.note.after))+sf.mt.dur.mc*f.s.jaccard+(1|song_individual)+(1|class.note.after)+(1|trans.type)+(1|class.note.after:song_individual)+(1|class.note.before:song_individual)+(1|class.note.before:class.note.after:song_individual)+(1|clutch),data=gls,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=100000)))
summary(gd.lme)
AICc(gd.lme)

#Plot the results. We could plot every note, but the figure is so crowded that it is not very useful. So, instead, we will plot just the mean gap logged gap duration for each gap type produced by each bird.
xban=aggregate(log(gls$gap.duration),by=list(gls$gt.ind),mean)
colnames(xban)=c("gt.ind","log.gap.duration")
xban$gt.sf=gls$gt.sf[match(xban$gt.ind,gls$gt.ind)]
xban$sf.log.gap.duration=xban$log.gap.duration[match(xban$gt.sf,xban$gt.ind)]
xban$note.before=gls$class.note.before[match(xban$gt.ind,gls$gt.ind)]
xban$note.after=gls$class.note.after[match(xban$gt.ind,gls$gt.ind)]
xban$bird.id=gls$song_individual[match(xban$gt.ind,gls$gt.ind)]
xban$cross.foss=(meta.data$Social.Father[match(xban$bird.id,meta.data$Bird.ID)]!=meta.data$Genetic.Father[match(xban$bird.id,meta.data$Bird.ID)]) | (!is.na(meta.data$Social.Father[match(xban$bird.id,meta.data$Bird.ID)]) & is.na(meta.data$Genetic.Father[match(xban$bird.id,meta.data$Bird.ID)]))
xban.short=xban[which(!is.na(xban$sf.log.gap.duration)),]

note.list=sort(unique(c(xban.short$note.before,xban.short$note.after)))
nb.num=(1:12)[match(xban.short$note.before,note.list)]
na.num=(1:12)[match(xban.short$note.after,note.list)]

plot.range=c(min(xban.short$log.gap.duration)-0.05*(max(xban.short$log.gap.duration)-min(xban.short$log.gap.duration)),max(xban.short$log.gap.duration)+0.05*(max(xban.short$log.gap.duration)-min(xban.short$log.gap.duration)))
axismin=min(xban.short$log.gap.duration)-0.05*(max(xban.short$log.gap.duration)-min(xban.short$log.gap.duration))
axismax=max(xban.short$log.gap.duration)+0.05*(max(xban.short$log.gap.duration)-min(xban.short$log.gap.duration))

####create separate graphs for note before and note after with custom axis ticks
plot(xban.short$sf.log.gap.duration,xban.short$log.gap.duration,col=paletteer_c("ggthemes::Sunset-Sunrise Diverging", 12)[nb.num],pch=16-1*xban$cross.foss,cex=0.8,xlab="social father mean logged gap duration (s)",ylab="son mean logged gap duration (s)",xlim=plot.range,ylim=plot.range, xaxt="n", yaxt="n")
axis(1, at = seq(-6, 0, 1), labels = seq(-6, 0, 1), lwd=0, lwd.ticks=2, tck=-0.035)
axis(2, at = seq(-6, 0, 1), labels = seq(-6, 0, 1), lwd=0, lwd.ticks=2, tck=-0.035)

plot(xban.short$sf.log.gap.duration,xban.short$log.gap.duration,col=paletteer_c("ggthemes::Sunset-Sunrise Diverging", 12)[na.num],pch=16-1*xban$cross.foss,cex=0.8,xlab="social father mean logged gap duration (s)",ylab="son mean logged gap duration (s)",xlim=plot.range,ylim=plot.range, xaxt="n", yaxt="n")
axis(1, at = seq(-6, 0, 1), labels = seq(-6, 0, 1), lwd=0, lwd.ticks=2, tck=-0.035)
axis(2, at = seq(-6, 0, 1), labels = seq(-6, 0, 1), lwd=0, lwd.ticks=2, tck=-0.035)

###both on the same graph with custom axis ticks 
plot(xban.short$sf.log.gap.duration,xban.short$log.gap.duration,col=paletteer_c("grDevices::Viridis", 12)[nb.num],pch=19-4*xban$cross.foss,cex=1.2,xlab="Social Father Mean Logged Gap Duration (s)",ylab="Son Mean Logged Gap Duration (s)",xlim=plot.range,ylim=plot.range,xaxt="n", yaxt="n")
points(xban.short$sf.log.gap.duration,xban.short$log.gap.duration,col=paletteer_c("grDevices::Viridis", 12)[na.num],pch=19-4*xban$cross.foss,cex=0.7,xlab="Social Father Mean Logged Gap Duration (s)",ylab="Son Mean Logged Gap Duration (s)")
axis(1, at = seq(-6, 0, 1), labels = seq(-6, 0, 1), lwd=0, lwd.ticks=2, tck=-0.035)
axis(2, at = seq(-6, 0, 1), labels = seq(-6, 0, 1), lwd=0, lwd.ticks=2, tck=-0.035)




#########################################
'This section studies whether birds with longer songs (measured in numbers of notes) have faster tempos' 
#########################################

plot(temp.metrics$mean.notes.per.song,temp.metrics$mean.logged.song.tempo,xlab="mean notes per song",ylab="mean logged song tempo (log(notes/s))")
tempo.on.notes=lm(mean.logged.song.tempo~mean.notes.per.song,data=temp.metrics)
summary(tempo.on.notes)
AICc(tempo.on.notes)